@@ -23,11 +23,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.15
+Version v3.0.17
 
 =cut
 
-our $VERSION = version->declare("v3.0.15");
+our $VERSION = version->declare("v3.0.17");
 
 =head1 SYNOPSIS
 
@@ -156,6 +156,12 @@ has skipped => (
 );
 
 has deb_fmt => (
+	is      => 'rw',
+	lazy    => 1,
+	default => sub { $_[0]->deb_machine },
+);
+
+has deb_machine => (
 	is => 'rw',
 );
 
@@ -417,9 +423,8 @@ sub parse_license
 		when ( /unless such copies or derivative works are solely in the form of machine-executable object code generated by a source language processor/ ) {
 			break;
 		}
-		when ( /(All changes made in this file will be lost|DO NOT ((?:HAND )?EDIT|delete this file|modify)|edit the original|Generated (automatically|by|from|data|with)|generated.*file)/i ) {
+		when ( /(All changes made in this file will be lost|DO NOT ((?:HAND )?EDIT|delete this file|modify)|edit the original|Generated (automatically|by|from|data|with)|generated.*file|auto[- ]generated)/i ) {
 			$license = "GENERATED FILE";
-			push @spdx_license, 'generated-file';
 		}
 	}
 	given ($licensetext) {
